@@ -63,6 +63,7 @@ __all__ = (
     "CreateBackendAuthResourceConfigTypeDef",
     "CreateBackendAuthResponseTypeDef",
     "CreateBackendAuthUserPoolConfigTypeDef",
+    "CreateBackendAuthVerificationMessageConfigTypeDef",
     "CreateBackendConfigRequestRequestTypeDef",
     "CreateBackendConfigResponseTypeDef",
     "CreateBackendRequestRequestTypeDef",
@@ -130,6 +131,7 @@ __all__ = (
     "UpdateBackendAuthResourceConfigTypeDef",
     "UpdateBackendAuthResponseTypeDef",
     "UpdateBackendAuthUserPoolConfigTypeDef",
+    "UpdateBackendAuthVerificationMessageConfigTypeDef",
     "UpdateBackendConfigRequestRequestTypeDef",
     "UpdateBackendConfigResponseTypeDef",
     "UpdateBackendJobRequestRequestTypeDef",
@@ -457,6 +459,7 @@ _OptionalCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
         "Mfa": "CreateBackendAuthMFAConfigTypeDef",
         "OAuth": "CreateBackendAuthOAuthConfigTypeDef",
         "PasswordPolicy": "CreateBackendAuthPasswordPolicyConfigTypeDef",
+        "VerificationMessage": "CreateBackendAuthVerificationMessageConfigTypeDef",
     },
     total=False,
 )
@@ -468,6 +471,29 @@ class CreateBackendAuthUserPoolConfigTypeDef(
     pass
 
 
+_RequiredCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "DeliveryMethod": DeliveryMethodType,
+    },
+)
+_OptionalCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthVerificationMessageConfigTypeDef(
+    _RequiredCreateBackendAuthVerificationMessageConfigTypeDef,
+    _OptionalCreateBackendAuthVerificationMessageConfigTypeDef,
+):
+    pass
+
+
 _RequiredCreateBackendConfigRequestRequestTypeDef = TypedDict(
     "_RequiredCreateBackendConfigRequestRequestTypeDef",
     {
@@ -1322,10 +1348,34 @@ UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
         "Mfa": "UpdateBackendAuthMFAConfigTypeDef",
         "OAuth": "UpdateBackendAuthOAuthConfigTypeDef",
         "PasswordPolicy": "UpdateBackendAuthPasswordPolicyConfigTypeDef",
+        "VerificationMessage": "UpdateBackendAuthVerificationMessageConfigTypeDef",
     },
     total=False,
 )
 
+_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "DeliveryMethod": DeliveryMethodType,
+    },
+)
+_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateBackendAuthVerificationMessageConfigTypeDef(
+    _RequiredUpdateBackendAuthVerificationMessageConfigTypeDef,
+    _OptionalUpdateBackendAuthVerificationMessageConfigTypeDef,
+):
+    pass
+
+
 _RequiredUpdateBackendConfigRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateBackendConfigRequestRequestTypeDef",
     {
